aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/libs/curl/src/tool_formparse.c
diff options
context:
space:
mode:
authorthegeorg <thegeorg@yandex-team.com>2024-10-11 21:07:18 +0300
committerthegeorg <thegeorg@yandex-team.com>2024-10-11 21:17:24 +0300
commit1df197e6035ea9826bfedee7d48812e318ba9c7a (patch)
tree76b8e9de41820755adf209854d06a84a8b5a1988 /contrib/libs/curl/src/tool_formparse.c
parentf9c007ea1b59b960201def74990810b26ecdfd48 (diff)
downloadydb-1df197e6035ea9826bfedee7d48812e318ba9c7a.tar.gz
Revert "Update contrib/libs/curl to 8.10.1" to fix
Revert "Update contrib/libs/curl to 8.10.1" This reverts commit 428ef806a15515cdaa325530aa8cc6903fac5fb6, reversing changes made to 40e46e6394df409d1545a3771c8a47a86ed55eac. Revert "Fix formatting after rXXXXXX" This reverts commit a73689311a92e195d14136c5a0049ef1e40b1f3e, reversing changes made to 17980b8756d1f74d3dacddc7ca4945c30f35611c. commit_hash:5c5194831e5455b61fbee61619066396626beab1
Diffstat (limited to 'contrib/libs/curl/src/tool_formparse.c')
-rw-r--r--contrib/libs/curl/src/tool_formparse.c14
1 files changed, 8 insertions, 6 deletions
diff --git a/contrib/libs/curl/src/tool_formparse.c b/contrib/libs/curl/src/tool_formparse.c
index 15918d3ee5..fa38698d5e 100644
--- a/contrib/libs/curl/src/tool_formparse.c
+++ b/contrib/libs/curl/src/tool_formparse.c
@@ -25,6 +25,8 @@
#include "strcase.h"
+#define ENABLE_CURLX_PRINTF
+/* use our own printf() functions */
#include "curlx.h"
#include "tool_cfgable.h"
@@ -276,7 +278,7 @@ static CURLcode tool2curlparts(CURL *curl, struct tool_mime *m,
case TOOLMIME_STDIN:
if(!filename)
filename = "-";
- FALLTHROUGH();
+ /* FALLTHROUGH */
case TOOLMIME_STDINDATA:
ret = curl_mime_data_cb(part, m->size,
(curl_read_callback) tool_mime_stdin_read,
@@ -635,7 +637,7 @@ static int get_param_part(struct OperationConfig *config, char endchar,
*pfilename = filename;
else if(filename)
warnf(config->global,
- "Field filename not allowed here: %s", filename);
+ "Field file name not allowed here: %s", filename);
if(pencoder)
*pencoder = encoder;
@@ -691,7 +693,7 @@ static int get_param_part(struct OperationConfig *config, char endchar,
* 'name=foo;headers=@headerfile' or why not
* 'name=@filemame;headers=@headerfile'
*
* To upload a file, but to fake the filename that will be included in the
* formpost, do like this:
*
* 'name=@filename;filename=/dev/null' or quote the faked filename like:
@@ -718,7 +720,7 @@ int formparse(struct OperationConfig *config,
struct tool_mime **mimecurrent,
bool literal_value)
{
- /* input MUST be a string in the format 'name=contents' and we will
+ /* input MUST be a string in the format 'name=contents' and we'll
build a linked list with the info */
char *name = NULL;
char *contents = NULL;
@@ -777,7 +779,7 @@ int formparse(struct OperationConfig *config,
}
else if('@' == contp[0] && !literal_value) {
/* we use the @-letter to indicate filename(s) */
struct tool_mime *subparts = NULL;
@@ -829,7 +831,7 @@ int formparse(struct OperationConfig *config,
SET_TOOL_MIME_PTR(part, encoder);
/* *contp could be '\0', so we just check with the delimiter */
- } while(sep); /* loop if there is another filename */
+ } while(sep); /* loop if there's another file name */
part = (*mimecurrent)->subparts; /* Set name on group. */
}
else {
@@ -691,7 +693,7 @@ static int get_param_part(struct OperationConfig *config, char endchar,
* 'name=@filemame;headers=@headerfile'
*
- * To upload a file, but to fake the filename that will be included in the
+ * To upload a file, but to fake the file name that will be included in the
* formpost, do like this:
*
@@ -777,7 +779,7 @@ int formparse(struct OperationConfig *config,
}
else if('@' == contp[0] && !literal_value) {
- /* we use the @-letter to indicate filename(s) */
+ /* we use the @-letter to indicate file name(s) */
struct tool_mime *subparts = NULL;